@@ -121,4 +121,4 @@ this.orbitals.get(i).put("type", "alpha");
 }return isUHF;
 });
 });
-;//5.0.1-v7 Mon Jul 21 08:59:16 CDT 2025
+;//5.0.1-v7 Thu Feb 05 13:38:23 CST 2026
