@@ -87,4 +87,4 @@ atoms[i].partialCharge = this.parseFloat();
 }
 });
 });
-;//5.0.1-v7 Mon Jul 21 08:59:16 CDT 2025
+;//5.0.1-v7 Thu Feb 05 13:38:23 CST 2026
