@@ -224,4 +224,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v7 Mon Jul 21 08:59:16 CDT 2025
+;//5.0.1-v7 Tue Feb 10 09:16:45 CST 2026
