@@ -53,4 +53,4 @@ function(n){
 return this.calcs.ff.minimizer.isLoggable(this.iData, n);
 }, "~N");
 })();
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Thu Feb 05 13:38:23 CST 2026
