@@ -46,4 +46,4 @@ this.calcs.addForces(this, 2);
 return this.energy;
 }, "~A");
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Thu Feb 05 13:38:23 CST 2026
