@@ -12,7 +12,7 @@ this.position = "fit to page";
 this.showGrid = true;
 this.showXScale = true;
 this.showYScale = true;
-this.showTitle = true;
+this.showTitles = true;
 this.font = "Helvetica";
 this.paper = null;
 this.asPDF = true;
@@ -32,4 +32,4 @@ this.asPDF = true;
 pd.setDefaultPrintOptions(this);
 }}, "JSV.common.PanelData");
 })();
-;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
+;//5.0.1-v7 Mon Feb 09 20:45:46 CST 2026
